<?php
/**
 * 本文抜粋
 * @since 1.6.0
 * @return string
 */
function stbl_get_post_excerpt( $post_id = null, $length = null ) {

	if ( $length === 0 ) {
		return "";
	}
	
	$length = $length ?: 30;
	$excerpt = '';

	$post_data = get_post( $post_id );

	if ( empty( $post_data ) ) return '';

	if ( has_excerpt( $post_id ) ) {
		$excerpt = get_the_excerpt( $post_id );
		$excerpt = stbl_sanitize_excerpt( $excerpt);
		$has_suffix = false;
		if ( mb_strwidth( $excerpt, 'UTF-8' ) > $length * 2  ) {
			$has_suffix = true;
		}

		$excerpt = mb_strimwidth( $excerpt, 0, $length * 2 , '', 'UTF-8' );
		if ( $has_suffix  ) {
			$excerpt .= '...';
		}
	} elseif ( ! empty( $post_data->post_password ) ) {
		$excerpt = '';
	} else {
		$excerpt = stbl_get_excerpt( $post_id, $length );
	}

	return $excerpt;
}

/**
 * 抜粋、descriptionなどを無害化
 *
 * @param string $content 抜粋、descriptionなど
 * @param boolean $do_shortcode ショートコードを実行するか
 * @return string 無害化されたテキスト
 * @version 0.1.0
 */
if (!function_exists('stbl_sanitize_excerpt')) {
	function stbl_sanitize_excerpt($content, $do_shortcode = true)
	{

		if ($do_shortcode) $content = do_shortcode($content);

		$content = strip_shortcodes($content); //展開できなかったショートコードは削除
		$content = str_replace( '[mokuji]', '', $content );
		$content = strip_tags($content);
		$content = stbl_delete_breaks($content);
		$content = stbl_trim_same_space($content);

		return $content;
	}
}

/**
 * ショートコード展開後の抜粋を取得
 *
 * @param int $length 最大文字数
 * @param int $post_id 記事ID
 * @param bool $do_shortcode ショートコードを展開するか
 * @return string 記事の抜粋
 * @version 0.1.0
 */
if (!function_exists('stbl_get_excerpt')) {
	function stbl_get_excerpt($post_id = null, $length = 140, $do_shortcode = true)
	{
		try {
			if ($post_id) {
				$post = get_post($post_id);
			} else {
				global $post;
			}

			$suffix = '...';
			$content = $post->post_content;
			$excerpt = stbl_sanitize_excerpt($content, $do_shortcode);
			$has_suffix = false;
			if ( mb_strwidth( $excerpt, 'UTF-8' ) > $length * 2  ) {
				$has_suffix = true;
			}

			$excerpt = mb_strimwidth($excerpt, 0, $length * 2, '', 'UTF-8');

			if ( $has_suffix ) {
				$excerpt .= $suffix;
			}

			return $excerpt;
		} catch (Exception $error) {
			return '';
		}
		
	}
}