<?php

function stbl_get_category_post($attributes) {
    
    $selected_style = ! empty( $attributes["className"] ) ? $attributes["className"] : 'is-style-default';

    $classname = "wp-block-streetist-blocks-category-post" . ' ' . $selected_style;

    /**
     * 投稿数
     */
    $num = ( ! empty( $attributes['num'] ) && is_numeric( $attributes['num' ]) )
        ? $attributes['num']
        : 5;

    if ( is_string( $num ) ) $num = intval( $num );

    $sticky = get_option('sticky_posts'); //先頭固定の記事

    if ( !empty($sticky) ) $num -= count( $sticky );

    if ( $num <= 0) $num = 1;

    /**
     * 日付
     */
    if ( isset( $attributes['dateType'] ) && ! empty( $attributes['dateType'] ) ) {
        $date_type = $attributes['dateType'];
    } else {
        $date_type = 'post-update';
    }

    /**
     * 抜粋
     */
    $has_excerpt = false;
    $excerpt_length = 60;
    
    if ( isset( $attributes['hasExcerpt'] ) && ! empty( $attributes['hasExcerpt'] ) ) {
        $has_excerpt = $attributes['hasExcerpt'];
    }

    if ( isset( $attributes['excerptLength'] ) && ! empty( $attributes['excerptLength'] ) ) {
        $excerpt_length = $attributes['excerptLength'];
        $excerpt_length = intval( $excerpt_length );
    }

    /**
     * クラス名
     */
    $list_class = 'stbl-entries';

    if ( isset( $attributes['mColumn'] ) && is_numeric( $attributes['mColumn'] ) ) {
        $list_class .= ' stbl-entries--m-column-' . $attributes['mColumn'];
    }

    if ( isset( $attributes['tColumn'] ) && is_numeric( $attributes['tColumn'] ) ) {
        $list_class .= ' stbl-entries--t-column-' . $attributes['tColumn'];
    }

    if ( isset( $attributes['pColumn'] ) && is_numeric( $attributes['pColumn'] ) ) {
        $list_class .= ' stbl-entries--p-column-' . $attributes['pColumn'];
    }

    /**
     * style
     */
    $style = '';

    if ( isset( $attributes['pMt'] ) && is_string( $attributes['pMt'] ) ) {
        $style .= '--stbl-entries-p-mt:' . $attributes['pMt'] . ';';
    }

    if ( isset( $attributes['pMb'] ) && is_string( $attributes['pMb'] ) ) {
        $style .= '--stbl-entries-p-mb:' . $attributes['pMb'] . ';';
    }

    if ( isset( $attributes['tMt'] ) && is_string( $attributes['tMt'] ) ) {
        $style .= '--stbl-entries-t-mt:' . $attributes['tMt'] . ';';
    }

    if ( isset( $attributes['tMb'] ) && is_string( $attributes['tMb'] ) ) {
        $style .= '--stbl-entries-t-mb:' . $attributes['tMb'] . ';';
    }

    if ( isset( $attributes['mMt'] ) && is_string( $attributes['mMt'] ) ) {
        $style .= '--stbl-entries-m-mt:' . $attributes['mMt'] . ';';
    }

    if ( isset( $attributes['mMb'] ) && is_string( $attributes['mMb'] ) ) {
        $style .= '--stbl-entries-m-mb:' . $attributes['mMb'] . ';';
    }

    if ( isset( $attributes['borderColor'] ) && is_string( $attributes['borderColor'] ) ) {
        $style .= '--stbl-entries-border-color:' . $attributes['borderColor'] . ';';
    }

    if ( isset( $attributes['borderWidth'] ) && is_numeric( $attributes['borderWidth'] ) ) {
        $style .= '--stbl-entries-border-width:' . $attributes['borderWidth'] . 'px;';
    }
    /**
     * カテゴリーID
     */
    $catId = 0;

    if ( isset( $attributes['catId'] ) && is_numeric( $attributes['catId'] ) ) {
        $catId = $attributes['catId'];
    }

    $args = array(
        'posts_per_page'  => $num,
        'cat' => $catId,
    );

    $wp_query = new WP_Query( $args );

    ob_start();
?>
    <div class="<?php echo $classname; ?>" style="<?php echo $style; ?>">
        <?php if ( $wp_query->have_posts() ) : ?>
            <div class="<?php echo $list_class ?>">
                <?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
                    <?php
                    $post_id = get_the_ID();
                    $title = get_the_title();
                    $title = stbl_mb_substr_text( $title, 100 );
                    $title = esc_attr( $title );

					$thumb_data = stbl_get_thumbnail_info( $post_id, "large" );

                    $has_thumb = $thumb_data && isset( $thumb_data[0] ) && $thumb_data[0];

                    $excerpt = '';

                    if ($has_excerpt) {
                        $excerpt = stbl_get_post_excerpt( $post_id, $excerpt_length );
                    }
                    ?>
                    <div class="stbl-entries-item">
                        <a href="<?php echo get_the_permalink(); ?>" class="stbl-entries-item__inner">
                            <figure class="stbl-entries-item__thumb">
                                <?php if ( $has_thumb ): ?>
                                    <img src="<?php echo $thumb_data[0]; ?>" width="<?php echo $thumb_data[1]; ?>" height="<?php echo $thumb_data[2]; ?>" alt="<?php echo $title; ?>" loading="lazy" />
                                <?php endif; ?>
                            </figure>
                            <div class="stbl-entries-item__content">
                                <?php stbl_get_post_date_tag( $post_id, $date_type ); ?>
                                <p class="stbl-entries-item__ttl">
                                    <?php echo $title; ?>
                                </p>
                                <?php if ( $has_excerpt ) : ?>
                                    <p class="stbl-entries-item__excerpt">
                                        <?php echo $excerpt; ?>
                                    </p>
                                <?php endif; ?>
                            </div>
                        </a>
                    </div>
                <?php endwhile; ?>
            </div>
        <?php else : ?>
            <p class="stbl-no-entry">記事はありません。</p>
        <?php endif; ?>
    </div>
<?php
    $content = ob_get_clean();

    wp_reset_postdata();

    return $content;
}

function stbl_register_block_category_post() {
	register_block_type('streetist-blocks/category-post', array(
		'editor_script' => 'editor-script-streetist-blocks',
		'editor_style' => 'editor-style-streetist-blocks',
		'script' => 'script-streetist-blocks',
		'style' => 'style-streetist-blocks',
		'attributes' 	=> array(
			'num' => array(
				'type' => 'string',
			),
			'catId' => array(
				'type' => 'string',
            ),
            'dateType' => array(
				'type' => 'string',
                'default' => 'post-update'
            ),
            'hasExcerpt' => array(
                'type' => 'boolean',
                'default' => false,
            ),
            'excerptLength' => array(
                'type' => 'number',
                'default' => '60',
            ),
            'borderColor' => array(
				'type' => 'string',
            ),
            'borderWidth' => array(
				'type' => 'number',
                'default' => 1,
            ),
            'mColumn' => array(
				'type'		=> 'number',
				'default'	=> 1
			),
			'tColumn' => array(
				'type'		=> 'number',
				'default'	=> 2
			),
			'pColumn' => array(
				'type'		=> 'number',
				'default'	=> 2
			),
            'pMt' => array(
				'type' => 'string',
			),
            'pMb' => array(
				'type' => 'string',
			),
            'tMt' => array(
				'type' => 'string',
			),
            'tMb' => array(
				'type' => 'string',
			),
            'mMt' => array(
				'type' => 'string',
			),
            'mMb' => array(
				'type' => 'string',
			),
		),
		'render_callback'	=> 'stbl_get_category_post',
	));
}
add_action('init', 'stbl_register_block_category_post');