<?php 
/**
 *
 * プラグインに必要な設定
 *
 * @since   1.0.0
 * @package streetist-blocks
 */

defined( 'ABSPATH' ) || exit;

load_plugin_textdomain(
	'streetist-blocks',
	false,
	basename( dirname( __FILE__ ) ) . '/languages'
);

/**
 * javascript・CSSの読み込み
 *
 * @since 1.0.0
 * @return void
 */
function stbl_register_block_type($block, $options = array()) {

	register_block_type(
		'streetist-blocks/' . $block,
		array_merge(
			array(
				'editor_script' => 'editor-script-streetist-blocks',
				'editor_style' => 'editor-style-streetist-blocks',
				'script' => 'script-streetist-blocks',
				'style' => 'style-streetist-blocks',
			),
			$options
		)
	);
}

/**
 * javascript・CSSの読み込み
 *
 * @since 1.0.0
 * @return void
 */

function stbl_gutenberg_register_block() {

	if ( ! function_exists( 'register_block_type' ) ) {
		return;
	}

	wp_register_style(
		'style-streetist-blocks',
		plugins_url( 'dist/style.css',__FILE__ ),
		array(),
		STBL_VERSION
	);

	wp_register_script(
		'script-streetist-blocks',
		plugins_url( 'dist/script.js', __FILE__ ),
		array(),
		STBL_VERSION,
		array(
			'strategy' => 'async',
			'in_footer' => true,
		),
	);

	wp_register_style(
		'editor-style-streetist-blocks',
		plugins_url( 'dist/editor.css', __FILE__ ),
		array( 'wp-edit-blocks' ),
		STBL_VERSION
	);

	wp_register_script(
		'editor-script-streetist-blocks',
		plugins_url('dist/editor.js', __FILE__),
		array('wp-blocks', 'wp-i18n','wp-element', 'wp-block-editor', 'wp-components', 'wp-element', 'lodash', 'wp-blob', 'wp-data', 'wp-server-side-render', 'wp-rich-text' ),
		STBL_VERSION
	);

	stbl_register_block_type('button');
	stbl_register_block_type('afi-button');
	stbl_register_block_type('box');
	stbl_register_block_type('fukidashi');
	stbl_register_block_type('limited-time');
	stbl_register_block_type('list-box');
	stbl_register_block_type('micro-copy');
	stbl_register_block_type('qa');
	stbl_register_block_type('simple-box');
	stbl_register_block_type('timeline');
	stbl_register_block_type('timeline-item');
	stbl_register_block_type('toggle');

}
add_action( 'init', 'stbl_gutenberg_register_block' );

function stbl_admin_scripts() {
    
    wp_enqueue_script('wp-color-picker');
    wp_enqueue_script(
        'streetist-blocks-admin-script',
        plugins_url('dist/admin.js', __FILE__),
        array(
            'wp-color-picker',
            'jquery'
        ),
        STBL_VERSION,
    );
}
add_action( 'admin_enqueue_scripts', 'stbl_admin_scripts' );

function stbl_admin_styles() {
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_style(
        'streetist-blocks-admin-style',
        plugins_url('dist/admin.css', __FILE__),
        array(),
        STBL_VERSION
    );
}

add_action( 'admin_print_scripts', 'stbl_admin_styles' );

/**
 * オリジナルのカスタムブロックを追加
 *
 * @since 1.0.0
 * @return void
 */
function stbl_gutenberg_register_block_category( $categories ) {

	array_splice(
        $categories,
        0, // 指定の位置
        0,
        array(
            array(
                'slug' => 'stbl-category-contents',
                'title' => __('【STREETIST】コンテンツ', 'streetist-blocks'),
            ),
			array(
                'slug' => 'stbl-category-cta',
                'title' => __('【STREETIST】CTA', 'streetist-blocks'),
            ),
			array(
                'slug' => 'stbl-category-section',
                'title' => __('【STREETIST】セクション', 'streetist-blocks'),
            ),
			array(
                'slug' => 'stbl-category-layout',
                'title' => __('【STREETIST】レイアウト', 'streetist-blocks'),
            ),
			array(
                'slug' => 'stbl-category-front-page',
                'title' => __('【STREETIST】トップページ用', 'streetist-blocks'),
            ),
        )
    );

	// 最後に追加
	$array = array_merge(
		$categories,
		array(
			array(
				'slug'  => 'stbl_block',
				'title' => '【STREETIST】旧バージョン（非推奨）'
			),
		)
	);

	return $array;
}
if (version_compare($GLOBALS['wp_version'], '5.8-alpha-1', '<')) {
    add_filter('block_categories', 'stbl_gutenberg_register_block_category', 10, 2);
} else {
    add_filter('block_categories_all', 'stbl_gutenberg_register_block_category', 10, 2);
}


/**
 * ウィジェットにクラス名を追加
 */
function stbl_widget_add_classname( $classname, $block_name ) {

    switch ( $block_name ) {
        case 'streetist-blocks/related-entry':
            $classname .= ' widget--related-entry';
            break;
    }
    
    return $classname;
}
add_filter( 'widget_block_dynamic_classname', 'stbl_widget_add_classname', 10, 2 );

